@@ -24,12 +24,15 @@
 #' dsn.  Vegetation species-level data with one record for each species
 #' (P2VEG_SUBPLOT_SPP).
 #' @param vsubpstr DF/DT, R object, comma-delimited file(*.csv), or layer in
-#' dsn.  Vegetation species-structure data with one record for each species
+#' dsn. Vegetation species-structure data with one record for each species
 #' (P2VEG_SUBP_STRUCTURE).
+#' @param invsubp DF/DT, R object, comma-delimited file(*.csv), or layer in
+#' dsn. Invasive species data with one record for each species
+#' (INVASIVE_SUBPLOT_SPP).
 #' @param subplot DF/DT, R object, comma-delimited file(*.csv), or layer in
-#' dsn.  Subplot-level data with one record for each species (SUBPLOT).
+#' dsn. Subplot-level data with one record for each species (SUBPLOT).
 #' @param subp_cond DF/DT, R object, comma-delimited file(*.csv), or layer in
-#' dsn.  Subplot condition-level data with one record for each species
+#' dsn. Subplot condition-level data with one record for each species
 #' (SUBP_COND).
 #' @param lulc DF/DT, R object, comma-delimited file(*.csv), or layer in dsn.
 #' Land use/Land cover data with current and previous observations.
@@ -41,9 +44,10 @@
 #' popTables(cond = FIESTA::WYcond, seed = FIESTA::WYseed)
 #' @export popTables
 
-popTables <- function(cond=NULL, plt=NULL, tree=NULL,
-                             seed=NULL, vsubpspp=NULL, vsubpstr=NULL, 
-                             subplot=NULL, subp_cond=NULL, lulc=NULL, ...) {
+popTables <- function(cond=NULL, plt=NULL, 
+                      tree=NULL, seed=NULL, 
+                      vsubpspp=NULL, vsubpstr=NULL, invsubp=NULL,
+                      subplot=NULL, subp_cond=NULL, lulc=NULL, ...) {
   # Check input parameters
   input.params <- names(as.list(match.call()))[-1]
   formallst <- c(names(formals(popTables)))
